@@ -4,17 +4,35 @@ import argparse
 import sys
 import os
 import time
+from colorama import Fore, Style, init
+import redis
+
+redis_client = redis.Redis.from_url(os.environ.get("PLUK_REDIS_URL"), decode_responses=True)
+
+init(autoreset=True)
+
+def get_repo_info():
+    repo_url = redis_client.get("repo_url")
+    commit_sha = redis_client.get("commit_sha")
+    if not repo_url or not commit_sha:
+        return None, None
+    return repo_url, commit_sha
 
 # Initialize a repository
 def cmd_init(args):
     """
     Initialize a repository at the specified path.
 
-    This command sets up the necessary structure for Pluk to operate,
-    and is necessary to run before using repository commands.
+    This command queues a full index job for a repository.
 
-    Immediately parses the repository, indexing its contents
-    into the Pluk database.
+    IMPORTANT: the repository to be indexed must be public (or otherwise
+    directly accessible from the worker container). Workers clone repositories
+    using the repository URL; private repositories that require credentials are
+    not supported by the host shim workflow. When `pluk init /path/to/repo` is
+    invoked on the host, the shim extracts the repo's remote URL and commit
+    SHA and forwards them into the CLI container via the environment
+    variables `PLUK_REPO_URL` and `PLUK_REPO_COMMIT_SHA` before asking the
+    API to enqueue the reindex job.
     """
     import requests
     print(f"Initializing repository at {args.path}")
@@ -53,6 +71,10 @@ def cmd_init(args):
             time.sleep(0.1)
 
         sys.stdout.write(f"\r[+] Repository initialized successfully.                                       ")
+        print("\nCurrent repository:")
+        repo_url, commit_sha = get_repo_info()
+        print(f"    URL: {repo_url}")
+        print(f"    Commit SHA: {commit_sha}")
     else:
         print(f"Error initializing repository: {reindex_res.status_code}")
     return
@@ -61,9 +83,9 @@ def cmd_start(args):
     """
     Start the Pluk services.
 
-    This command starts all the required Docker containers for Pluk,
-    including the database, worker, and API services.
-    It will create the necessary Docker Compose configuration if it doesn't exist.
+    NOTE: Starting/stopping/status commands are handled by the host shim (`pluk`)
+    and affect Docker Compose on the host. Invoking `start` inside the CLI
+    container (`plukd`) is a no-op; use the host shim command `pluk start`.
     """
     return
 
@@ -71,8 +93,9 @@ def cmd_cleanup(args):
     """
     Stop the Pluk services.
 
-    This command stops all running Pluk Docker containers,
-    but does not remove data volumes.
+    NOTE: This is a host-level command handled by the shim (`pluk`). Use
+    `pluk cleanup` on the host to stop the Docker Compose stack. Running this
+    inside the CLI container does not perform host-level cleanup.
     """
     return
 
@@ -80,19 +103,20 @@ def cmd_status(args):
     """
     Check the status of Pluk services.
 
-    This command checks if all required Pluk services are running
-    and reports their current status.
+    NOTE: Service lifecycle commands (`start`, `status`, `cleanup`) are
+    implemented in the host shim. Use `pluk status` on the host to inspect the
+    current Docker Compose state.
     """
     return
 
 def cmd_search(args):
     """
-    Search for a symbol in the current repository.
-
-    This command allows users to find symbols by name, and list its references
+    Fuzzy search for symbols in the current indexed commit. Uses the
+    repository currently registered with the service (see `pluk init`).
     """
     import requests
-    print(f"Searching for symbol: {args.symbol}")
+    repo_url, commit_sha = get_repo_info()
+    print(f"{Fore.CYAN}Searching for symbol: {args.symbol} @ {repo_url if repo_url else 'unknown'}:{commit_sha if commit_sha else 'unknown'}\n")
     # Make a request to the Pluk API to search for the symbol
     res = requests.get(f"{os.environ.get('PLUK_API_URL')}/search/{args.symbol}")
     if res.status_code == 200:
@@ -101,16 +125,14 @@ def cmd_search(args):
         for symbol in res_obj['symbols'] or []:
             print(f"Found symbol: {symbol['name']}")
             # Location: file:line@commit
-            print(f"Located at: {symbol['location']}@{symbol['commit']}")
-            print("References:")
-            for ref in symbol['references'] or []:
-                print(f" - {ref}")
-            if not symbol['references']:
-                print("No references found.")
+            print(f"Located at: {symbol['location']}")
+            print()
         if not res_obj['symbols']:
             print("No symbols found.")
     else:
         print(f"Error searching for symbol: {res.status_code}")
+        print("     Please ensure the repository indexed is public and reachable by the worker container.")
+        print("     Also ensure your latest changes are pushed to 'origin' so they are available for search.")
 
 def cmd_define(args):
     """
@@ -123,14 +145,15 @@ def cmd_define(args):
     """
     import requests
     print(f"Defining symbol: {args.symbol}")
+    print()
     # Make a request to the Pluk API to define the symbol
     # API returns the symbol definition and its location
     res = requests.get(f"{os.environ.get('PLUK_API_URL')}/define/{args.symbol}")
     if res.status_code == 200:
         res_obj = res.json()
         print(f"Symbol definition: {res_obj['definition']}")
-        # Location: file:line@commit
-        print(f"Located at: {res_obj['location']}@{res_obj['commit']}")
+        # Location: file:line
+        print(f"Located at: {res_obj['location']}")
     else:
         print(f"Error defining symbol: {res.status_code}")
 
@@ -138,11 +161,10 @@ def cmd_impact(args):
     """
     Analyze the impact of a symbol in the codebase.
 
-    Shows everything that depends on the symbol, transitively.
-    Starts with direct callers/users, then expands to callers of those callers,
-    importers of importers, subclass chains, etc.
-
-    Scope: transitive closure over the dependency graph (calls/imports/inheritance).
+    Shows everything that depends on the symbol in the current repository.
+    This command allows users to understand the potential impact of
+    changes to a symbol by listing all symbols, including their
+    files and lines, that reference it.
     """
     import requests
     print(f"Analyzing impact of symbol: {args.symbol}")
@@ -151,13 +173,24 @@ def cmd_impact(args):
     if res.status_code == 200:
         res_obj = res.json()
         # Process the response JSON and list impacted files
-        print("Impacted files:")
-        for file in res_obj['impacted_files'] or []:
-            print(f" - {file}")
-        if not res_obj['impacted_files']:
-            print("No impacted files found.")
+        # Outputs formatted: {"file": path, "line": line,
+                            # "container": cont_node.text.decode() if cont_node else None,
+                            # "container_kind": cont_node.type if cont_node else None}
+        print("References found:")
+        for ref in res_obj['symbol_references'] or []:
+            print(f" - {ref.get('container', '<scope unknown>')} ({ref.get('container_kind', '<kind unknown>')}) in {ref.get('file', '<file unknown>')}:{ref.get('line', '<line unknown>')}")
+            print()
+        if not res_obj['symbol_references']:
+            print("No symbol references found.")
+    elif res.status_code == 404:
+        print("Symbol not found.")
+    elif res.status_code == 405:
+        print("Language not supported.")
+        print("Please refer to the documentation for supported languages.")
+    elif res.status_code == 500:
+        print("Repository not initialized.")
     else:
-        print(f"Error analyzing impact: {res.status_code}")
+        print(f"Internal server error: {res.status_code}")
 
 def cmd_diff(args):
     """
